example

package module
v0.0.0-...-341fdd1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 8, 2020 License: Apache-2.0 Imports: 1 Imported by: 0

README

library-example-go

build codecov GoDoc Go Report Card License

This repository has the purpose of giving a full example on how to manage an open-source library in GitHub by configuring workflows, adding badges, documenting and testing.

⚠ it is in continuos development

Install

go get github.com/AFMiziara/library-example-go

Usage

Describe here with as much detail you can provide how to use your library. Try to give examples for each functionality available.

Documentation

Overview

Package example contains irrelevant functions for demonstrating purpose only

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Greeting

func Greeting(name string) string

Greeting is a simple function that says hello to the person's name received as a parameter

Types

This section is empty.

Jump to